//+------------------------------------------------------------------+
//|                                                    ATR_Bands.mq4 |
//| ATR Bands are self-adjusting enveloppes, based on the volatility |
//|        Based on BB indicator, modified by kris.pivo[at]gmail.com |
//+------------------------------------------------------------------+
#property copyright " 2008, Kris"

#property indicator_chart_window
#property indicator_buffers 7
#property indicator_color1  White
#property indicator_style1  STYLE_DASH
#property indicator_color2  Gold
#property indicator_color3  Gold
#property indicator_color4  Magenta
#property indicator_color5  RoyalBlue

//---- indicator parameters

extern int    Price                = PRICE_MEDIAN;
extern int    Bands_Shift          = 0;
extern int    ATR_Period           = 5;
extern double ATR_Multiplier       = 1.5;
extern double b                    = 1.00;
extern double timefactor           = 1;// 1=timeframe used, if higher tf for instance on 1hr chart want h4 band timefactor should =4 
extern color  LineColor            = Yellow;
extern int    FuzzR                =  255;
extern int    FuzzG                =  0;
extern int    FuzzB                =  0;
extern int    VisualMode           =  0;   //0-DC+Corona,1-DC,2-Corona 
extern int    CoronaBars           =  1000;
extern bool   alertsOn             = false;
extern bool   alertsOnCurrent      = false;
extern bool   alertsOnHighLow      = true;
extern bool   alertsMessage        = true;
extern bool   alertsSound          = false;
extern bool   alertsEmail          = false;

//---- buffers
double MovingBuffer[];
double UpperBuffer[];
double LowerBuffer[];
double UpperBuffer2[];
double LowerBuffer2[];
double UpperBuffer3[];
double LowerBuffer3[];
int    HalfLength;
int    T3_Period;
//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
//---- indicators
   SetIndexStyle( 0,DRAW_LINE,STYLE_DASH,0,indicator_color1);
   SetIndexBuffer(0,MovingBuffer);
   SetIndexStyle( 1,DRAW_LINE,STYLE_SOLID,2,indicator_color2);
   SetIndexBuffer(1,UpperBuffer);
   SetIndexStyle( 2,DRAW_LINE,STYLE_SOLID,2,indicator_color3);
   SetIndexBuffer(2,LowerBuffer);
   SetIndexStyle( 3,DRAW_LINE,STYLE_SOLID,2,indicator_color4);
   SetIndexBuffer(3,UpperBuffer2);
   SetIndexStyle( 4,DRAW_LINE,STYLE_SOLID,2,indicator_color5);
   SetIndexBuffer(4,LowerBuffer2);
   SetIndexStyle( 5,DRAW_LINE,STYLE_SOLID,2,indicator_color4);
   SetIndexBuffer(5,UpperBuffer3);
   SetIndexStyle( 6,DRAW_LINE,STYLE_SOLID,2,indicator_color5);
   SetIndexBuffer(6,LowerBuffer3);
//----
   SetIndexDrawBegin(0,HalfLength+Bands_Shift);
   SetIndexDrawBegin(1,HalfLength+Bands_Shift);
   SetIndexDrawBegin(2,HalfLength+Bands_Shift);
   SetIndexDrawBegin(4,HalfLength+Bands_Shift);
   SetIndexDrawBegin(5,HalfLength+Bands_Shift);
   SetIndexDrawBegin(6,HalfLength+Bands_Shift);
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Bollinger Bands                                                  |
//+------------------------------------------------------------------+
int start()
  {
   int    i,k,counted_bars=IndicatorCounted();
   double TrueRange;
   double sum,oldval; //newres;
   HalfLength = iCustom(NULL,0,"CoronaCyclePeriod_v2.1",Price,LineColor,FuzzR,FuzzG,FuzzB,VisualMode,CoronaBars,0,i)/2*timefactor;
   T3_Period = iCustom(NULL,0,"CoronaCyclePeriod_v2.1",Price,LineColor,FuzzR,FuzzG,FuzzB,VisualMode,CoronaBars,0,i)/2*timefactor; 
//----
   if(Bars<=HalfLength) return(0);
//---- initial zero
   if(counted_bars<1)
      for(i=1;i<=HalfLength;i++)
        {
         MovingBuffer[Bars-i]=EMPTY_VALUE;
         UpperBuffer[Bars-i] =EMPTY_VALUE;
         LowerBuffer[Bars-i] =EMPTY_VALUE;
         UpperBuffer2[Bars-i]=EMPTY_VALUE;
         LowerBuffer2[Bars-i]=EMPTY_VALUE;
         UpperBuffer3[Bars-i]=EMPTY_VALUE;
         LowerBuffer3[Bars-i]=EMPTY_VALUE;
        }
//----
   int limit=Bars-counted_bars;
   if(counted_bars>0) limit++;
   for(i=0; i<limit; i++)
      MovingBuffer[i]=iCustom(NULL,0,"TMAcentered",HalfLength,Price,0,i);
//----
   i=Bars-HalfLength+1;
   if(counted_bars>HalfLength-1) i=Bars-counted_bars-1;
   while(i>=0)
     {
      sum=0.0;
      k=i+HalfLength-1;
      oldval=MovingBuffer[i];
      TrueRange=ATR_Multiplier*iCustom(NULL,0,"ATR_T3_v1.2",ATR_Period,T3_Period,b,false,0,i);
      UpperBuffer[i]=oldval+TrueRange;
      LowerBuffer[i]=oldval-TrueRange;
      UpperBuffer2[i]=oldval+TrueRange*2;
      LowerBuffer2[i]=oldval-TrueRange*2;
      UpperBuffer3[i]=oldval+TrueRange*3;
      LowerBuffer3[i]=oldval-TrueRange*3;
      i--;
     }
//----
   if (alertsOn)
   {
      if (alertsOnCurrent)
            int forBar = 0;
      else      forBar = 1;
      if (alertsOnHighLow)       
      {
         if (High[forBar]>UpperBuffer3[forBar] && High[forBar+1]<UpperBuffer3[forBar+1]) doAlert("high penetrated upper bar");
         if (Low[forBar] <LowerBuffer3[forBar] && Low[forBar+1] >LowerBuffer3[forBar+1]) doAlert("low penetrated lower bar");
      }
      else
      {
         if (Close[forBar]>UpperBuffer3[forBar] && Close[forBar+1]<UpperBuffer3[forBar+1]) doAlert("close penetrated upper bar");
         if (Close[forBar]<LowerBuffer3[forBar] && Close[forBar+1]>LowerBuffer3[forBar+1]) doAlert("close penetrated lower bar");
      }
   }   
   return(0);
}

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
//
//
//
//
//

void doAlert(string doWhat)
{
   static string   previousAlert="";
   static datetime previousTime;
   string message;

   //
   //
   //
   //
   //
   
   if (previousAlert!=doWhat || previousTime!=Time[0]) 
   {
      previousAlert = doWhat;
      previousTime  = Time[0];

      message= StringConcatenate(Symbol()," at ",TimeToStr(TimeLocal(),TIME_SECONDS)," TMA : ",doWhat);
         if (alertsMessage) Alert(message);
         if (alertsEmail)   SendMail(StringConcatenate(Symbol(),"TMA "),message);
         if (alertsSound)   PlaySound("alert2.wav");
    }
}
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~+
//                                       THE END                                        |
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~+

